import { useRef } from 'react';
import { FiChevronLeft, FiChevronRight } from 'react-icons/fi';
import MediaCard from './MediaCard';

function MediaCarousel({ title, media = [], mediaType = 'movie', seeAllLink }) {
  const carouselRef = useRef(null);

  const scroll = (direction) => {
    if (carouselRef.current) {
      const { current } = carouselRef;
      const scrollAmount = direction === 'left' 
        ? -current.offsetWidth * 0.8 
        : current.offsetWidth * 0.8;
      
      current.scrollBy({
        left: scrollAmount,
        behavior: 'smooth',
      });
    }
  };

  if (!media.length) {
    return null;
  }

  return (
    <div className="my-8">
      <div className="flex justify-between items-center mb-4">
        <h2 className="text-2xl font-bold">{title}</h2>
        {seeAllLink && (
          <a href={seeAllLink} className="text-campfire-amber hover:text-campfire-ember">
            See All
          </a>
        )}
      </div>
      
      <div className="relative">
        {/* Left Navigation Arrow */}
        <button
          onClick={() => scroll('left')}
          className="absolute left-0 top-1/2 -translate-y-1/2 z-10 bg-campfire-dark bg-opacity-50 hover:bg-opacity-75 p-2 rounded-full text-campfire-light transition-all transform -translate-x-1/2 opacity-0 group-hover:opacity-100 group-hover:translate-x-0 duration-300"
          aria-label="Scroll left"
        >
          <FiChevronLeft size={24} />
        </button>

        {/* Carousel Container */}
        <div
          ref={carouselRef}
          className="flex overflow-x-auto pb-4 -mx-4 px-4 scrollbar-hide group"
          style={{
            scrollbarWidth: 'none',
            msOverflowStyle: 'none',
          }}
        >
          {media.map((item) => (
            <div key={item.id} className="min-w-[180px] md:min-w-[220px] px-2 flex-shrink-0">
              <MediaCard media={item} type={mediaType} />
            </div>
          ))}
        </div>

        {/* Right Navigation Arrow */}
        <button
          onClick={() => scroll('right')}
          className="absolute right-0 top-1/2 -translate-y-1/2 z-10 bg-campfire-dark bg-opacity-50 hover:bg-opacity-75 p-2 rounded-full text-campfire-light transition-all transform translate-x-1/2 opacity-0 group-hover:opacity-100 group-hover:translate-x-0 duration-300"
          aria-label="Scroll right"
        >
          <FiChevronRight size={24} />
        </button>
      </div>
    </div>
  );
}

export default MediaCarousel;